@@ -1,7 +1,7 @@
 package Software::Catalog::SW::zotero;
 
-our $DATE = '2018-09-22'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2018-10-04'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -12,13 +12,13 @@ use Software::Catalog::Util qw(extract_from_url);
 
 use Role::Tiny::With;
 with 'Software::Catalog::Role::Software';
-#with 'Software::Catalog::Role::VersionScheme::SemVer';
 
 our %SPEC;
 
 sub meta {
     return {
         homepage_url => "https://www.zotero.org/",
+        versioning_scheme => "Dotted",
     };
 }
 
@@ -85,9 +85,7 @@ sub get_download_url {
 sub get_programs {
     my ($self, %args) = @_;
     [200, "OK", [
-        {name=>"zcoin-cli", path=>"/bin"},
-        {name=>"zcoin-qt", path=>"/bin"},
-        {name=>"zcoind", path=>"/bin"},
+        {name=>"zotero", path=>"/"},
     ]];
 }
 
@@ -106,7 +104,7 @@ Software::Catalog::SW::zotero - Zotero
 
 =head1 VERSION
 
-This document describes version 0.002 of Software::Catalog::SW::zotero (from Perl distribution Software-Catalog-SW-zotero), released on 2018-09-22.
+This document describes version 0.003 of Software::Catalog::SW::zotero (from Perl distribution Software-Catalog-SW-zotero), released on 2018-10-04.
 
 =for Pod::Coverage ^(.+)$
 
